def to_lower_text(self, text: str) -> str:

    """
    Метод to_lower_text меняет все заглавные символы в тексте на прописные

    return text.lower() - Возвращает текст с заменеными в нем заглывными буквами на прописные
    """

    return text.lower()
