from ._to_lower import to_lower_text
from ._emoji_cleaner import clean_emoji
from ._spaces_cleaner import clean_spaces
from ._html_cleaner import clean_html
from ._punctuation_cleaner import clean_punctuation
from ._clean_stopwords import clean_stopwords
from ._to_morpheme import text_to_morphems

from .TextCleaner import TextCleaner
